Module layer

Module layer 

Structs

BearerAuthLayer
Tower layer that injects a bearer token into outbound HTTP requests.
BearerAuthService
Tower service that injects a bearer token header before forwarding the request to the inner service.