pub struct AuthDispatcher { /* private fields */ }Expand description
Central dispatcher for JWT and opaque token validation
Orchestrates key providers and claims plugins to validate tokens using a single configured plugin.
Implementations
Sourceimpl AuthDispatcher
impl AuthDispatcher
Sourcepub fn new(
validation_config: ValidationConfig,
config: &AuthConfig,
registry: &PluginRegistry,
) -> Result<Self, ConfigError>
pub fn new( validation_config: ValidationConfig, config: &AuthConfig, registry: &PluginRegistry, ) -> Result<Self, ConfigError>
Create a new dispatcher with validation config and plugin.
Errors
Returns ConfigError::UnknownPlugin if the configured provider is not in the registry.
Sourcepub fn with_key_provider(self, provider: Arc<dyn KeyProvider>) -> Self
pub fn with_key_provider(self, provider: Arc<dyn KeyProvider>) -> Self
Add a key provider
Sourcepub fn with_introspection_provider(
self,
provider: Arc<dyn IntrospectionProvider>,
) -> Self
pub fn with_introspection_provider( self, provider: Arc<dyn IntrospectionProvider>, ) -> Self
Add an introspection provider
Sourcepub async fn validate_jwt(&self, token: &str) -> Result<Claims, ClaimsError>
pub async fn validate_jwt(&self, token: &str) -> Result<Claims, ClaimsError>
Validate a JWT token.
Workflow:
- Try each
KeyProvideruntil one successfully validates the signature - Extract issuer from token
- Use the configured plugin to normalize claims
- Run common validation (issuer, audience, exp, nbf, UUIDs)
- Return normalized claims
Errors
Returns ClaimsError if signature validation, claim normalization, or validation fails.
Sourcepub async fn validate_opaque(&self, token: &str) -> Result<Claims, ClaimsError>
pub async fn validate_opaque(&self, token: &str) -> Result<Claims, ClaimsError>
Validate an opaque token via introspection
Workflow:
- Try each
IntrospectionProvideruntil one succeeds - Extract issuer from introspection response
- Use the configured plugin to normalize claims
- Run common validation
- Return normalized claims
Errors
Returns ClaimsError if introspection, claim normalization, or validation fails.
Sourcepub fn validation_config(&self) -> &ValidationConfig
pub fn validation_config(&self) -> &ValidationConfig
Get validation config (for inspection/testing)
Sourcepub fn plugin(&self) -> &Arc<dyn ClaimsPlugin>
pub fn plugin(&self) -> &Arc<dyn ClaimsPlugin>
Get the configured authentication plugin (for inspection/testing)
Sourcepub async fn refresh_keys(&self) -> Result<(), Vec<ClaimsError>>
pub async fn refresh_keys(&self) -> Result<(), Vec<ClaimsError>>
Trigger key refresh for all key providers.
Errors
Returns a vector of ClaimsError if any provider fails to refresh keys.