Module layer
modkit_
auth
0.2.7
Module layer
Module Items
Structs
In modkit_
auth::
oauth2
modkit_auth
::
oauth2
Module
layer
Structs

Bearer
Auth
Layer
Tower layer that injects a bearer token into outbound HTTP requests.
Bearer
Auth
Service
Tower service that injects a bearer token header before forwarding the request to the inner service.